==> breeze_update_3.6.05.tar.gz: manage/remove_menu_code.php <==
<?php
/////////////////////////////////////////////
// Remove Menu Code /////
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 11/13/2009	ELL
// Revised: 2/9/2012	ELL
// Added table prefix handling.
//
// 
//
	include ("check_session.php");
	
	$today = addslashes(date("m/d/Y  H:m:s"));
	
	// Remove code from selected border area.
	$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '$border_area'";
	$result = mysql_query($query, $bwb_link);
	$row = mysql_fetch_array($result);
	$page_content = $row["page_content"];
	
	$pos = strrpos($page_content, "new menu (MENU");
	if ($pos !== false)
	{
		$pos2 = $pos + strlen("new menu (MENU_ITEMS");
		$pos3 = strpos($page_content, ",", $pos);
		$lnth = $pos3 - $pos2;
		$suf = substr($page_content, $pos2, $lnth);
		$searchStr = "<script language=\"JavaScript\"> new menu (MENU" . $suf . "_ITEMS, MENU" . $suf . "_POS); </script>";
		$page_content = str_replace($searchStr, "", $page_content);
	
		$page_content=addslashes($page_content);
		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content='$page_content', revised='$today' WHERE page_name='$border_area'";
		$result = mysql_query($query, $bwb_link);
//		echo "<br>Removed menu code from $border_area.<br>";
	}
//	else
//		echo "<br>Note: Menu code in border $border_area area not found.<br>";
?>

==> breeze_update_4.0.01.tar.gz: manage/remove_menu_code.php <==
<?php
/////////////////////////////////////////////
// Remove Menu Code /////
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 11/13/2009	ELL
// Revised: 2/9/2012	ELL
// Added table prefix handling.
//
// 
//
	include ("check_session.php");
	
	$today = addslashes(date("m/d/Y  H:m:s"));
	
	// Remove code from selected border area.
	$query = "SELECT page_content FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name = '$border_area'";
	$result = $bwb_dbh->query($query);
	$row = $result->fetch(PDO::FETCH_ASSOC);
	$page_content = $row["page_content"];
	
	$pos = strrpos($page_content, "new menu (MENU");
	if ($pos !== false)
	{
		$pos2 = $pos + strlen("new menu (MENU_ITEMS");
		$pos3 = strpos($page_content, ",", $pos);
		$lnth = $pos3 - $pos2;
		$suf = substr($page_content, $pos2, $lnth);
		$searchStr = "<script language=\"JavaScript\"> new menu (MENU" . $suf . "_ITEMS, MENU" . $suf . "_POS); </script>";
		$page_content = str_replace($searchStr, "", $page_content);
	
		$page_content=addslashes($page_content);
		$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_special SET page_content='$page_content', revised='$today' WHERE page_name='$border_area'";
		$cnt = $bwb_dbh->exec($query);
//		echo "<br>Removed menu code from $border_area.<br>";
	}
//	else
//		echo "<br>Note: Menu code in border $border_area area not found.<br>";
?>
